This function makes it easy to get an overview of available data:

  • table_data() returns a tibble with details of the network datasets included in the packages.

table_data(..., pkg = c("manynet", "migraph"))

Arguments

...

Network marks, e.g. directed, twomode, or signed, that are used to filter the results.

pkg

String, name of the package.

Examples

table_data()
#> # A tibble: 36 × 15
#>    dataset          nodes  ties nattr layers directed weighted twomode labelled
#>    <char>           <dbl> <dbl> <dbl>  <dbl> <logi>   <logi>   <logi>  <logi>  
#>  1 ison_koenigsberg     4     7     3      1 FALSE    FALSE    FALSE   TRUE    
#>  2 irps_wwi             6    20     1      1 FALSE    FALSE    FALSE   TRUE    
#>  3 ison_adolescents     8    10     1      1 FALSE    FALSE    FALSE   TRUE    
#>  4 irps_corruption     11    44     3      3 FALSE    FALSE    FALSE   TRUE    
#>  5 ison_brandes        11    12     1      1 FALSE    FALSE    FALSE   FALSE   
#>  6 ison_bankwiring     14   110     2      6 TRUE     TRUE     FALSE   TRUE    
#>  7 irps_tribes         16    58     1      1 FALSE    FALSE    FALSE   TRUE    
#>  8 ison_algebra        16   279     0      3 TRUE     TRUE     FALSE   FALSE   
#>  9 ison_florentine     16    35     4      2 FALSE    FALSE    FALSE   TRUE    
#> 10 ison_fraternity     17  4080     1      1 TRUE     TRUE     FALSE   TRUE    
#> # ℹ 26 more rows
#> # ℹ 6 more variables: signed <logi>, longitudinal <logi>, dynamic <logi>,
#> #   changing <logi>, acyclic <logi>, attributed <logi>
# to obtain list of all e.g. directed networks:
table_data(pkg = "manynet", directed)
#> # A tibble: 15 × 15
#>    dataset         nodes  ties nattr layers directed weighted twomode labelled
#>    <char>          <dbl> <dbl> <dbl>  <dbl> <logi>   <logi>   <logi>  <logi>  
#>  1 ison_bankwiring    14   110     2      6 TRUE     TRUE     FALSE   TRUE    
#>  2 ison_algebra       16   279     0      3 TRUE     TRUE     FALSE   FALSE   
#>  3 ison_fraternity    17  4080     1      1 TRUE     TRUE     FALSE   TRUE    
#>  4 ison_emotions      18   315     1      1 TRUE     TRUE     FALSE   TRUE    
#>  5 ison_monks         18   463     3      4 TRUE     TRUE     FALSE   TRUE    
#>  6 ison_hightech      21   312     4      3 TRUE     FALSE    FALSE   FALSE   
#>  7 ison_classmates    26   546     7      2 TRUE     FALSE    FALSE   TRUE    
#>  8 ison_networkers    32   440     3      1 TRUE     TRUE     FALSE   TRUE    
#>  9 ison_judo_moves    33    81     1      1 TRUE     FALSE    FALSE   TRUE    
#> 10 ison_tailorshop    39   637     1      2 TRUE     FALSE    FALSE   TRUE    
#> 11 fict_potter        64   544     5      1 TRUE     FALSE    FALSE   TRUE    
#> 12 ison_lawfirm       71  2571     7      3 TRUE     FALSE    FALSE   FALSE   
#> 13 fict_starwars     110   563    12      1 TRUE     TRUE     FALSE   TRUE    
#> 14 fict_thrones      208   404    10      2 TRUE     FALSE    FALSE   TRUE    
#> 15 irps_blogs       1490 19090     3      1 TRUE     FALSE    FALSE   TRUE    
#> # ℹ 6 more variables: signed <logi>, longitudinal <logi>, dynamic <logi>,
#> #   changing <logi>, acyclic <logi>, attributed <logi>
# to obtain overview of unique datasets:
table_data() |> 
  dplyr::distinct(directed, weighted, twomode, signed, 
                 .keep_all = TRUE)
#> # A tibble: 9 × 15
#>   dataset            nodes  ties nattr layers directed weighted twomode labelled
#>   <char>             <dbl> <dbl> <dbl>  <dbl> <logi>   <logi>   <logi>  <logi>  
#> 1 ison_koenigsberg       4     7     3      1 FALSE    FALSE    FALSE   TRUE    
#> 2 irps_wwi               6    20     1      1 FALSE    FALSE    FALSE   TRUE    
#> 3 ison_bankwiring       14   110     2      6 TRUE     TRUE     FALSE   TRUE    
#> 4 ison_algebra          16   279     0      3 TRUE     TRUE     FALSE   FALSE   
#> 5 ison_hightech         21   312     4      3 TRUE     FALSE    FALSE   FALSE   
#> 6 ison_southern_wom…    32    89     4      1 FALSE    FALSE    TRUE    TRUE    
#> 7 ison_karateka         34    78     2      1 FALSE    TRUE     FALSE   TRUE    
#> 8 fict_marvel          194  1241    11      2 FALSE    FALSE    TRUE    TRUE    
#> 9 irps_supremecourt    385  2300     3      1 FALSE    TRUE     TRUE    TRUE    
#> # ℹ 6 more variables: signed <logi>, longitudinal <logi>, dynamic <logi>,
#> #   changing <logi>, acyclic <logi>, attributed <logi>