R/manynet-glossary.R
glossary.Rd
This function adds a glossary item, useful in tutorials. Where no glossary entry exists for the term, the text is simply returned italicised.
gloss(text, ref = NULL) print_glossary() clear_glossary()
The text to appear.
The name of the glossary item to index. If NULL, then the function will search the glossary for 'text' instead.