These functions reformat the levels in manynet-consistent network data.
to_onemode() reformats two-mode network data into one-mode network data
by simply removing the nodeset 'type' information.
Note that this is not the same as to_mode1() or to_mode2();
it does not project the two-mode network into one of its modes,
but rather simply removes the distinction between the two modes.
to_twomode() reformats one-mode network data into two-mode network data,
using a mark to distinguish the two sets of nodes.
to_multilevel() reformats two-mode network data into multimodal network data,
which allows for more levels and ties within modes.
If the format condition is not met,
for example to_onemode() is used on a network that is already one-mode,
the network data is returned unaltered.
No warning is given so that these functions can be used to ensure conformance.
Unlike the as_*() group of functions,
these functions always return the same class as they are given,
only transforming these objects' properties.
to_onemode(.data)
to_twomode(.data, mark)
to_multilevel(.data)An object of a {manynet}-consistent class:
adjacency or incidence matrix from {base} R
edgelist data.frame from {base} R or tbl/tbl_df from {tibble}
stocnet stocnet, from the {manynet} package
igraph igraph, from the {igraph} package
network network, from the {network} package
tidygraph tbl_graph, from the {tidygraph} package
A logical vector marking two types or modes. By default "type".
An object of the same class as the function was given, modified as explained in the function description, details, or section. Functions that split a network return a list of such objects.
Not all functions have methods available for all object classes. Below are the currently implemented S3 methods:
Other modifications:
modif_backbone,
modif_direction,
modif_from,
modif_labels,
modif_miss,
modif_motifs,
modif_paths,
modif_permutation,
modif_plexity,
modif_project,
modif_proximity,
modif_scope,
modif_split,
modif_weight