These functions are used to describe components of a given network in terms of a particular phrase.
describe_network() describes the features or properties of a network,
such as whether it is two-mode, directed, or complex.
describe_nodes() describes how many of each type of nodes there are
and, if available, names the different nodesets or modes.
describe_ties() describes how many of each type of ties there are
and, if available, names the different types of ties.
describe_changes() describes the changing features of a network,
if any, such as how many waves there are.
These descriptions are constructed to be GRAND-consistent.
describe_network(.data)
describe_nodes(.data)
describe_ties(.data)
describe_changes(.data)