This function makes it easy to get an overview of available data:
table_data() returns a tibble with details of the
network datasets included in the packages.
table_data(..., pkg = c("manynet", "migraph"))table_data()
#> # A tibble: 28 × 16
#> dataset nodes ties nattr tattr directed weighted twomode labelled
#> <char> <dbl> <dbl> <dbl> <dbl> <logi> <logi> <logi> <logi>
#> 1 ison_koenigsberg 4 7 3 1 FALSE FALSE FALSE TRUE
#> 2 irps_wwi 6 20 1 3 FALSE FALSE FALSE TRUE
#> 3 ison_adolescents 8 10 1 0 FALSE FALSE FALSE TRUE
#> 4 ison_brandes 11 12 1 0 FALSE FALSE FALSE FALSE
#> 5 ison_algebra 16 279 0 2 TRUE TRUE FALSE FALSE
#> 6 ison_emotions 18 315 1 1 TRUE TRUE FALSE TRUE
#> 7 ison_monks 18 463 3 4 TRUE TRUE FALSE TRUE
#> 8 ison_hightech 21 312 4 1 TRUE FALSE FALSE FALSE
#> 9 ison_networkers 32 440 3 1 TRUE TRUE FALSE TRUE
#> 10 ison_southern_wom… 32 89 4 1 FALSE FALSE TRUE TRUE
#> # ℹ 18 more rows
#> # ℹ 7 more variables: signed <logi>, multiplex <logi>, longitudinal <logi>,
#> # dynamic <logi>, changing <logi>, acyclic <logi>, attributed <logi>
# to obtain list of all e.g. directed networks:
table_data(pkg = "manynet", directed)
#> # A tibble: 11 × 16
#> dataset nodes ties nattr tattr directed weighted twomode labelled
#> <char> <dbl> <dbl> <dbl> <dbl> <logi> <logi> <logi> <logi>
#> 1 ison_algebra 16 279 0 2 TRUE TRUE FALSE FALSE
#> 2 ison_emotions 18 315 1 1 TRUE TRUE FALSE TRUE
#> 3 ison_monks 18 463 3 4 TRUE TRUE FALSE TRUE
#> 4 ison_hightech 21 312 4 1 TRUE FALSE FALSE FALSE
#> 5 ison_networkers 32 440 3 1 TRUE TRUE FALSE TRUE
#> 6 ison_judo_moves 33 81 1 0 TRUE FALSE FALSE TRUE
#> 7 fict_potter 64 544 5 1 TRUE FALSE FALSE TRUE
#> 8 ison_lawfirm 71 2571 7 1 TRUE FALSE FALSE FALSE
#> 9 fict_starwars 110 563 12 2 TRUE TRUE FALSE TRUE
#> 10 fict_thrones 208 404 10 1 TRUE FALSE FALSE TRUE
#> 11 irps_blogs 1490 19090 3 0 TRUE FALSE FALSE TRUE
#> # ℹ 7 more variables: signed <logi>, multiplex <logi>, longitudinal <logi>,
#> # dynamic <logi>, changing <logi>, acyclic <logi>, attributed <logi>
# to obtain overview of unique datasets:
table_data() |>
dplyr::distinct(directed, weighted, twomode, signed,
.keep_all = TRUE)
#> # A tibble: 8 × 16
#> dataset nodes ties nattr tattr directed weighted twomode labelled
#> <char> <dbl> <dbl> <dbl> <dbl> <logi> <logi> <logi> <logi>
#> 1 ison_koenigsberg 4 7 3 1 FALSE FALSE FALSE TRUE
#> 2 irps_wwi 6 20 1 3 FALSE FALSE FALSE TRUE
#> 3 ison_algebra 16 279 0 2 TRUE TRUE FALSE FALSE
#> 4 ison_monks 18 463 3 4 TRUE TRUE FALSE TRUE
#> 5 ison_hightech 21 312 4 1 TRUE FALSE FALSE FALSE
#> 6 ison_southern_women 32 89 4 1 FALSE FALSE TRUE TRUE
#> 7 ison_karateka 34 78 2 1 FALSE TRUE FALSE TRUE
#> 8 fict_marvel 194 1241 11 2 FALSE FALSE TRUE TRUE
#> # ℹ 7 more variables: signed <logi>, multiplex <logi>, longitudinal <logi>,
#> # dynamic <logi>, changing <logi>, acyclic <logi>, attributed <logi>