R/data_irps.R
irps_supremecourt.RdA two-mode network of 376 US Supreme Court cases and the nine justices who sat together on the Rehnquist court between the 1995 and 2004 terms. This was the longest period in the court's history without a change in its membership, which makes the whole run comparable.
A tie indicates that a justice voted with the majority on a case, and is
weighted 1 for a full vote with the majority and 0.5 for a partial
concurrence.
One nodal attribute is included:
term: for cases, the court term in which the case was decided,
from 1995 to 2004. This is NA for the justices.
data(irps_supremecourt)#> -- # Rehnquist Court -----------------------------------------------------------
#> # A labelled, weighted, two-mode network of 376 cases and 9 justices and 2300
#> majority vote ties
#>
#> -- Nodes
#> # A tibble: 385 x 3
#> label mode term
#> <chr> <chr> <int>
#> 1 E001_Ada95 cases 1995
#> 2 E002_All95 cases 1995
#> 3 E003_Ari95 cases 1995
#> 4 E004_Asg95 cases 1995
#> 5 E005_Bab95 cases 1995
#> 6 E006_Cal95 cases 1995
#> # i 379 more rows
#>
#> -- Ties
#> # A tibble: 2,300 x 3
#> from to weight
#> <int> <int> <dbl>
#> 1 1 377 1
#> 2 2 377 1
#> 3 3 377 1
#> 4 4 377 1
#> 5 6 377 1
#> 6 7 377 1
#> # i 2,294 more rows
#>The UCINET standard dataset collection derives it from the Supreme Court Database.
Cases are labelled by an index and an abbreviation of the case name
followed by the two-digit term, so that E001_Ada95 is the first case of
the 1995 term. Justice names have been corrected to their standard
spelling.
Spaeth, Harold J. 1990. United States Supreme Court Judicial Database. Ann Arbor MI: Inter-university Consortium for Political and Social Research. doi:10.3886/icpsr09422
Doreian, Patrick, Paulette Lloyd, and Andrej Mrvar. 2013. "Partitioning large signed two-mode networks: Problems and prospects". Social Networks 35(2): 212-230. doi:10.1016/j.socnet.2012.01.002