These functions reformat manynet-consistent data.
to_anti() reformats network data into its complement, where only ties not present in the original network
are included in the new network.
Unlike the as_*() group of functions,
these functions always return the same class as they are given,
only transforming these objects' properties.
to_anti(.data)All to_ functions return an object of the same class as that provided.
So passing it an igraph object will return an igraph object
and passing it a network object will return a network object,
with certain modifications as outlined for each function.
Not all functions have methods available for all object classes. Below are the currently implemented S3 methods:
| data.frame | igraph | matrix | network | tbl_graph | |
| to_acyclic | 1 | 1 | 1 | 1 | 1 |
| to_anti | 1 | 1 | 1 | 1 | 1 |
| to_reciprocated | 1 | 1 | 1 | 1 | 1 |
| to_redirected | 1 | 1 | 1 | 1 | 1 |
Other modifications:
manip_as,
manip_correlation,
manip_deformat,
manip_direction,
manip_from,
manip_levels,
manip_miss,
manip_nodes,
manip_paths,
manip_permutation,
manip_preformat,
manip_project,
manip_scope,
manip_split,
manip_ties
to_anti(ison_southern_women)
#> # A labelled, two-mode network of 32 nodes and 163 ties
#>
#> ── Nodes
#> # A tibble: 32 × 2
#> type name
#> <lgl> <chr>
#> 1 FALSE Evelyn
#> 2 FALSE Laura
#> 3 FALSE Theresa
#> 4 FALSE Brenda
#> 5 FALSE Charlotte
#> 6 FALSE Frances
#> # ℹ 26 more rows
#>
#> ── Ties
#> # A tibble: 163 × 2
#> from to
#> <int> <int>
#> 1 1 25
#> 2 1 28
#> 3 1 29
#> 4 1 30
#> 5 1 31
#> 6 1 32
#> # ℹ 157 more rows
#>