These functions allow users to add and delete tie attributes:
add_tie_attribute() and mutate_ties() offer ways to add
a vector of values to a network as a tie attribute.
rename_ties() renames tie attributes.
bind_ties() appends the tie data from two networks and
join_ties() merges ties from two networks,
adding a tie attribute identifying the newly added ties.
Note that while add_*()/delete_*() functions operate similarly as comparable {igraph} functions,
mutate*(), bind*(), etc work like {tidyverse} or {dplyr}-style functions.
add_tie_attribute(.data, attr_name, vector)
mutate_ties(.data, ...)
rename_ties(.data, ...)
arrange_ties(.data, ...)
bind_ties(.data, ...)
join_ties(.data, object2, attr_name)
select_ties(.data, ...)
summarise_ties(.data, ...)An object of a {manynet}-consistent class:
matrix (adjacency or incidence) from {base} R
edgelist, a data frame from {base} R or tibble from {tibble}
igraph, from the {igraph} package
network, from the {network} package
tbl_graph, from the {tidygraph} package
Character string naming a nodal attribute. The attribute itself may be a logical mark, numeric measure, or character membership vector.
A vector of values for the new attribute.
Additional parameters and arguments passed on internally.
A second object to copy nodes or ties from.
A data object of the same class as the function was given.
Other ties:
manip_ties_num,
modif_direction,
modif_weight
Other manipulations:
manip_changes,
manip_info,
manip_nodes_attr,
manip_nodes_num,
manip_ties_num
other <- create_filled(4) |> mutate(name = c("A", "B", "C", "D"))
mutate_ties(other, form = 1:6) |> filter_ties(form < 4)
#>
#> ── # Filled network ────────────────────────────────────────────────────────────
#> # A labelled, multiplex, undirected network of 4 nodes and 3 ties
#>
#> ── Nodes
#> # A tibble: 4 × 1
#> name
#> <chr>
#> 1 A
#> 2 B
#> 3 C
#> 4 D
#>
#> ── Ties
#> # A tibble: 3 × 3
#> from to form
#> <int> <int> <int>
#> 1 1 2 1
#> 2 1 3 2
#> 3 1 4 3
#>
add_tie_attribute(other, "weight", c(1, 2, 2, 2, 1, 2))
#> ── # Filled network ────────────────────────────────────────────────────────────
#> # A labelled, weighted, undirected network of 4 nodes and 6 ties
#>
#> ── Nodes
#> # A tibble: 4 × 1
#> name
#> <chr>
#> 1 A
#> 2 B
#> 3 C
#> 4 D
#>
#> ── Ties
#> # A tibble: 6 × 3
#> from to weight
#> <int> <int> <dbl>
#> 1 1 2 1
#> 2 1 3 2
#> 3 1 4 2
#> 4 2 3 2
#> 5 2 4 1
#> 6 3 4 2
#>