These functions implement logical tests for various network properties.
All is_*() functions return a logical scalar (TRUE or FALSE).
is_longitudinal() marks networks TRUE if they contain multiple waves of data.
is_dynamic() marks networks TRUE if they contain time-stamped data.
is_changing() marks networks TRUE if they contain any nodal changes.
is_longitudinal(.data)
is_dynamic(.data)
is_changing(.data)An object of a {manynet}-consistent class:
adjacency or incidence matrix from {base} R
edgelist data.frame from {base} R or tbl/tbl_df from {tibble}
stocnet stocnet, from the {manynet} package
igraph igraph, from the {igraph} package
network network, from the {network} package
tidygraph tbl_graph, from the {tidygraph} package
Not all functions have methods available for all object classes. Below are the currently implemented S3 methods for these functions:
If a method is not available for a particular class, but a default method is, the default method will attempt to coerce the object to a class for which a method is defined, and then coerce the output back to the original class. If no method is available for any class, an error will be thrown.
Other marks:
mark_format_cognitive,
mark_format_node,
mark_format_tie
Other changes:
manip_changes
is_longitudinal(create_tree(5, 3))
#> [1] FALSE
is_dynamic(create_tree(3))
#> [1] FALSE
is_changing(fict_starwars)
#> [1] TRUE