These functions implement logical tests for various network properties. All is_*() functions return a logical scalar (TRUE or FALSE).

  • is_twomode() marks networks TRUE if they contain two sets of nodes.

  • is_labelled() marks networks TRUE if there is a 'names' attribute for the nodes.

  • is_attributed() marks networks TRUE if there are other nodal attributes than 'names' or 'type'.

  • is_egonet() marks networks TRUE if it is a list of networks where each network contains only one node and its ties.

is_twomode(.data)

is_labelled(.data)

is_attributed(.data)

is_egonet(.data)

Arguments

.data

An object of a {manynet}-consistent class:

  • matrix (adjacency or incidence) from {base} R

  • edgelist, a data frame from {base} R or tibble from {tibble}

  • igraph, from the {igraph} package

  • network, from the {network} package

  • tbl_graph, from the {tidygraph} package

See also

Examples

is_twomode(create_filled(c(2,2)))
#> [1] TRUE
is_labelled(create_empty(3))
#> [1] FALSE
is_attributed(ison_algebra)
#> [1] FALSE
is_egonet(fict_starwars)
#> [1] FALSE