These functions implement logical tests for various network properties.
All is_*() functions return a logical scalar (TRUE or FALSE).
is_twomode() marks networks TRUE if they contain two sets of nodes.
is_labelled() marks networks TRUE if there is a 'names' attribute
for the nodes.
is_attributed() marks networks TRUE if there are other nodal attributes
than 'names' or 'type'.
is_egonet() marks networks TRUE if it is a list of networks where each
network contains only one node and its ties.
is_twomode(.data)
is_labelled(.data)
is_attributed(.data)
is_egonet(.data)Other marks:
mark_format_change,
mark_format_tie
is_twomode(create_filled(c(2,2)))
#> [1] TRUE
is_labelled(create_empty(3))
#> [1] FALSE
is_attributed(ison_algebra)
#> [1] FALSE
is_egonet(fict_starwars)
#> [1] FALSE