R/measure_attributes.R
measure_attributes_ties.RdThese functions extract certain attributes from network data:
tie_attribute() returns an attribute's values for the ties in a network.
tie_weights() returns the weights of the ties in a network.
tie_signs() returns the signs of the ties in a network.
tie_is_twomode() returns whether each tie in a network is a cross-mode tie.
These functions are also often used as helpers within other functions.
tie_*() always return vectors the same length
as the number of ties in the network, respectively.
tie_attribute(.data, attr_name)
tie_weights(.data)
tie_signs(.data)
tie_is_twomode(.data)An object of a {manynet}-consistent class:
matrix (adjacency or incidence) from {base} R
edgelist, a data frame from {base} R or tibble from {tibble}
igraph, from the {igraph} package
network, from the {network} package
tbl_graph, from the {tidygraph} package
Character string naming a nodal attribute. The attribute itself may be a logical mark, numeric measure, or character membership vector.
Other measures:
measure_attributes_nodes,
measure_dims
tie_attribute(ison_algebra, "task_tie")
#> NULL
tie_weights(to_mode1(ison_southern_women))
#> `Evelyn-Laura` `Evelyn-Brenda` `Evelyn-Theresa` `Evelyn-Charlotte`
#> 1 6 6 7 3
#> # ... and 135 more values from this nodeset. Use `print_all(...)` to print all values.
tie_signs(to_uniplex(fict_marvel,"relationship"))
#> `Abomination-Abomination` `Abomination-Beast` `Abomination-Colossus`
#> 1 -1 -1 -1
#> # ... and 555 more values from this nodeset. Use `print_all(...)` to print all values.
tie_is_twomode(fict_actually)
#> `Aurelia-Jamie` `Aurelia-Scene 32` `Aurelia-Scene 38` `Aurelia-Scene 39`
#> 1 0 1 1 1
#> # ... and 185 more values from this nodeset. Use `print_all(...)` to print all values.