These functions describe the missingness in network data:

  • net_node_missing() returns the proportion of nodes that are missing in a network.

  • net_tie_missing() returns the proportion of ties that are missing in a network.

net_node_missing(.data)

net_tie_missing(.data)

Arguments

.data

An object of a {manynet}-consistent class:

  • adjacency or incidence matrix from {base} R

  • edgelist data.frame from {base} R or tbl/tbl_df from {tibble}

  • stocnet stocnet, from the {manynet} package

  • igraph igraph, from the {igraph} package

  • network network, from the {network} package

  • tidygraph tbl_graph, from the {tidygraph} package

Value

net_node_missing() and net_tie_missing() return a scalar