to_permuted() permutes the network using a Fisher-Yates shuffle
on both the rows and columns (for a one-mode network)
or on each of the rows and columns (for a two-mode network).
to_permuted(.data, with_attr = TRUE)An object of a {manynet}-consistent class:
matrix (adjacency or incidence) from {base} R
edgelist, a data frame from {base} R or tibble from {tibble}
igraph, from the {igraph} package
network, from the {network} package
tbl_graph, from the {tidygraph} package
Logical whether any attributes of the object should be retained. By default TRUE.
A tidygraph object modified as explained in the function description, details, or section.
Other modifications:
modif_correlation,
modif_direction,
modif_from,
modif_labels,
modif_levels,
modif_miss,
modif_paths,
modif_plexity,
modif_project,
modif_scope,
modif_split,
modif_weight