These functions wrap {cli} functions and elements
to build an attractive command line interface (CLI).
snet_progress_step() for progress steps.
snet_progress_along() for progress along a vector.
snet_progress_seq() for progress along a sequence.
snet_progress_nodes() for progress along the nodes of a network.
If you wish to receive fewer messages in the console,
run options(snet_verbosity = 'quiet').
snet_progress_step(..., .envir = parent.frame())
snet_progress_along(..., .envir = parent.frame())
snet_progress_seq(..., .envir = parent.frame())
snet_progress_nodes(..., .envir = parent.frame())
seq_nodes(.data)
seq_ties(.data)One or more character strings. For most of these functions, if multiple strings are passed these will be pasted together.
This argument is just to inherit the parent frame in the (likely) event that the function is used within another function.
An object of a {manynet}-consistent class:
adjacency or incidence matrix from {base} R
edgelist data.frame from {base} R or tbl/tbl_df from {tibble}
stocnet stocnet, from the {manynet} package
igraph igraph, from the {igraph} package
network network, from the {network} package
tidygraph tbl_graph, from the {tidygraph} package